"""Test the request model."""

from syrupy.assertion import SnapshotAssertion

from systembridgemodels.request import Request


def test_request(snapshot: SnapshotAssertion):
    """Test the request."""
    request = Request(
        token="abc123",
        id="abc123",
        event="EVENT_TEST",
        data={"test": "test"},
    )
    assert isinstance(request, Request)
    assert request == snapshot



"""GPUs."""

from __future__ import annotations

from dataclasses import dataclass

from ..helpers import filter_unexpected_fields


@filter_unexpected_fields
@dataclass(slots=True)
class GPU:
    """GPU."""

    id: str
    name: str
    core_clock: float | None = None
    core_load: float | None = None
    fan_speed: float | None = None
    memory_clock: float | None = None
    memory_load: float | None = None
    memory_free: float | None = None
    memory_used: float | None = None
    memory_total: float | None = None
    power_usage: float | None = None
    temperature: float | None = None



"""Model constants."""

from enum import StrEnum

from .keyboard_key import KeyboardKey
from .keyboard_text import KeyboardText
from .media_directories import MediaDirectory
from .media_files import MediaFile, MediaFiles
from .modules import Module, ModulesData
from .modules.battery import Battery
from .modules.cpu import CPU
from .modules.disks import Disks
from .modules.displays import Display
from .modules.gpus import GPU
from .modules.media import Media
from .modules.memory import Memory
from .modules.networks import Networks
from .modules.processes import Process
from .modules.sensors import Sensors
from .modules.system import System
from .notification import Notification
from .open_path import OpenPath
from .open_url import OpenUrl
from .response import Response


class Model(StrEnum):
    """Model Enums."""

    BATTERY = Module.BATTERY
    CPU = Module.CPU
    DATA = "data"
    DISKS = Module.DISKS
    DISPLAYS = Module.DISPLAYS
    GPUS = Module.GPUS
    KEYBOARD_KEY = "keyboard_key"
    KEYBOARD_TEXT = "keyboard_text"
    MEDIA = Module.MEDIA
    MEDIA_DIRECTORIES = "media_directories"
    MEDIA_FILE = "media_file"
    MEDIA_FILES = "media_files"
    MEMORY = Module.MEMORY
    NETWORKS = Module.NETWORKS
    NOTIFICATION = "notification"
    OPEN_PATH = "open_path"
    OPEN_URL = "open_url"
    PROCESSES = Module.PROCESSES
    RESPONSE = "response"
    SECRETS = "secrets"
    SENSORS = Module.SENSORS
    SETTINGS = "settings"
    SYSTEM = Module.SYSTEM


MODEL_MAP = {
    Model.BATTERY: Battery,
    Model.CPU: CPU,
    Model.DATA: ModulesData,
    Model.DISKS: Disks,
    Model.DISPLAYS: Display,  # Map to Display not list[Display] so it can be mapped
    Model.GPUS: GPU,  # Map to GPU not list[GPU] so it can be mapped
    Model.KEYBOARD_KEY: KeyboardKey,
    Model.KEYBOARD_TEXT: KeyboardText,
    Model.MEDIA_DIRECTORIES: MediaDirectory,  # Map to MediaDirectory not list[MediaDirectory] so it can be mapped
    Model.MEDIA_FILE: MediaFile,
    Model.MEDIA_FILES: MediaFiles,
    Model.MEDIA: Media,
    Model.MEMORY: Memory,
    Model.NETWORKS: Networks,
    Model.NOTIFICATION: Notification,
    Model.OPEN_PATH: OpenPath,
    Model.OPEN_URL: OpenUrl,
    Model.PROCESSES: Process,  # Map to Process not list[Process] so it can be mapped
    Model.RESPONSE: Response,
    Model.SENSORS: Sensors,
    Model.SYSTEM: System,
}



"""Displays."""
from __future__ import annotations

from dataclasses import dataclass

from ..helpers import filter_unexpected_fields


@filter_unexpected_fields
@dataclass(slots=True)
class Display:
    """Display."""

    id: str
    name: str
    resolution_horizontal: int
    resolution_vertical: int
    x: int
    y: int
    width: int | None = None
    height: int | None = None
    is_primary: bool | None = None
    pixel_clock: float | None = None
    refresh_rate: float | None = None



"""Test the keyboard_text model."""

from syrupy.assertion import SnapshotAssertion

from systembridgemodels.keyboard_text import KeyboardText


def test_keyboard_text(snapshot: SnapshotAssertion):
    """Test the keyboard_text."""
    keyboard_text = KeyboardText(
        text="Test",
    )
    assert isinstance(keyboard_text, KeyboardText)
    assert keyboard_text == snapshot



"""Memory."""

from __future__ import annotations

from dataclasses import dataclass

from ..helpers import filter_unexpected_fields


@filter_unexpected_fields
@dataclass(slots=True)
class MemorySwap:
    """Memory Swap."""

    total: int | None = None
    used: int | None = None
    free: float | None = None
    percent: float | None = None
    sin: int | None = None
    sout: int | None = None


@filter_unexpected_fields
@dataclass(slots=True)
class MemoryVirtual:
    """Memory Virtual."""

    total: int | None = None
    available: int | None = None
    percent: float | None = None
    used: int | None = None
    free: int | None = None
    active: int | None = None
    inactive: int | None = None
    buffers: int | None = None
    cached: int | None = None
    wired: int | None = None
    shared: int | None = None


@filter_unexpected_fields
@dataclass(slots=True)
class Memory:
    """Memory."""

    swap: MemorySwap | None = None
    virtual: MemoryVirtual | None = None

    def __post_init__(self) -> None:
        """Post Init."""
        if isinstance(self.swap, dict):
            self.swap = MemorySwap(**self.swap)

        if isinstance(self.virtual, dict):
            self.virtual = MemoryVirtual(**self.virtual)



"""Fixtures for GPU models."""
from systembridgemodels.modules.gpus import GPU

FIXTURE_GPUS = [
    GPU(
        id="abc123",
        name="name",
        core_clock=1000.0,
        core_load=100.0,
        fan_speed=100.0,
        memory_clock=1000.0,
        memory_load=100.0,
        memory_free=1000.0,
        memory_used=1000.0,
        memory_total=1000.0,
        power_usage=100.0,
        temperature=100.0,
    )
]



"""Notification."""
from __future__ import annotations

from dataclasses import dataclass
from typing import Any, cast


@dataclass(slots=True)
class Action:
    """Notification Action."""

    command: str
    label: str
    data: dict[str, Any] | None = None


@dataclass(slots=True)
class Audio:
    """Notification Audio."""

    source: str
    volume: float | None = None


@dataclass(slots=True)
class Notification:
    """Notification."""

    title: str
    message: str | None = None
    icon: str | None = None
    image: str | None = None
    actions: list[Action] | None = None
    timeout: float | None = None
    audio: Audio | None = None

    def __post_init__(self):
        """Post init."""
        if isinstance(self.actions, list) and all(
            isinstance(item, dict) for item in self.actions
        ):
            new_actions: list[Action] = []
            for a in self.actions:
                action = cast(dict, a)
                new_actions.append(Action(**action))
            self.actions = new_actions

        if isinstance(self.audio, dict):
            audio = cast(dict, self.audio)
            self.audio = Audio(**audio)



"""Action."""
from __future__ import annotations

from dataclasses import dataclass
from typing import Any


@dataclass(slots=True)
class Action:
    """Action."""

    command: str
    data: dict[str, Any] | None = None
    label: str | None = None



"""Test the media_files model."""

from dataclasses import asdict

from syrupy.assertion import SnapshotAssertion

from systembridgemodels.fixtures.media_files import FIXTURE_MEDIA_FILES
from systembridgemodels.media_files import MediaFile, MediaFiles


def test_media_files(snapshot: SnapshotAssertion):
    """Test the media_files."""
    media_files = FIXTURE_MEDIA_FILES
    assert isinstance(media_files, MediaFiles)
    assert isinstance(media_files.files, list)
    assert isinstance(media_files.files[0], MediaFile)
    assert media_files == snapshot


def test_media_files_dict(snapshot: SnapshotAssertion):
    """Test media files dict."""
    media_files_dict = asdict(FIXTURE_MEDIA_FILES)
    assert isinstance(media_files_dict, dict)
    assert media_files_dict == snapshot

    media_files_converted = MediaFiles(**media_files_dict)
    assert isinstance(media_files_converted, MediaFiles)
    assert media_files_converted == snapshot(
        name="media-files-dict-converted",
    )



"""Test the response model."""

from syrupy.assertion import SnapshotAssertion

from systembridgemodels.response import Response


def test_response(snapshot: SnapshotAssertion):
    """Test the response."""
    response = Response(
        id="abc123",
        type="TYPE_TEST",
        data={"test": "test"},
        subtype="SUBTYPE_TEST",
        message="MESSAGE_TEST",
        module="MODULE_TEST",
    )
    assert isinstance(response, Response)
    assert response == snapshot



"""Processes."""

from __future__ import annotations

from dataclasses import dataclass

from ..helpers import filter_unexpected_fields


@filter_unexpected_fields
@dataclass(slots=True)
class Process:
    """Process."""

    id: float
    name: str | None = None
    cpu_usage: float | None = None
    created: float | None = None
    memory_usage: float | None = None
    path: str | None = None
    status: str | None = None
    username: str | None = None
    working_directory: str | None = None



"""Test the OpenUrl model."""

from syrupy.assertion import SnapshotAssertion

from systembridgemodels.open_url import OpenUrl


def test_open_url(snapshot: SnapshotAssertion):
    """Test the open_url."""
    open_url = OpenUrl(
        url="https://www.example.com",
    )
    assert isinstance(open_url, OpenUrl)
    assert open_url == snapshot



"""Media Get Files."""
from __future__ import annotations

from dataclasses import dataclass


@dataclass(slots=True)
class MediaGetFiles:
    """Media Get Files."""

    base: str
    path: str | None = None



"""Test const."""

from syrupy.assertion import SnapshotAssertion

from systembridgemodels.const import MODEL_MAP


def test_model_map(snapshot: SnapshotAssertion):
    """Test the model_map."""
    assert isinstance(MODEL_MAP, dict)
    assert snapshot == MODEL_MAP



"""Fixture for media files."""
from systembridgemodels.media_files import MediaFile, MediaFiles

FIXTURE_MEDIA_FILES = MediaFiles(
    files=[
        MediaFile(
            name="file1",
            path="path/to/file1",
            fullpath="/full/path/to/file1",
            size=100,
            last_accessed=100.0,
            created=100.0,
            modified=100.0,
            is_directory=False,
            is_file=True,
            is_link=False,
            mime_type="text/plain",
        ),
    ],
    path="path/to/file",
)



"""Fixtures for media models."""
from systembridgemodels.modules.media import Media

FIXTURE_MEDIA = Media(
    album_artist="Album Artist",
    album_title="Album Title",
    artist="Artist",
    duration=100,
    is_fast_forward_enabled=True,
    is_next_enabled=True,
    is_pause_enabled=True,
    is_play_enabled=True,
    is_previous_enabled=True,
    is_rewind_enabled=True,
    is_stop_enabled=True,
    playback_rate=1.0,
    position=100,
    repeat="repeat",
    shuffle=True,
    status="status",
    subtitle="subtitle",
    thumbnail="thumbnail",
    title="title",
    track_number=1,
    type="type",
    updated_at=100,
)



"""Test the media_control model."""

from syrupy.assertion import SnapshotAssertion

from systembridgemodels.media_control import MediaAction, MediaControl


def test_media_control(snapshot: SnapshotAssertion):
    """Test the media_control."""
    media_control = MediaControl(
        action=MediaAction.PLAY.value,
        value=True,
    )
    assert isinstance(media_control, MediaControl)
    assert media_control == snapshot



"""CPU."""

from __future__ import annotations

from dataclasses import dataclass
from typing import cast

from ..helpers import filter_unexpected_fields


@filter_unexpected_fields
@dataclass(slots=True)
class CPUFrequency:
    """CPU Frequency."""

    current: float | None = None
    min: float | None = None
    max: float | None = None


@filter_unexpected_fields
@dataclass(slots=True)
class CPUStats:
    """CPU Stats."""

    ctx_switches: int | None = None
    interrupts: int | None = None
    soft_interrupts: int | None = None
    syscalls: int | None = None


@filter_unexpected_fields
@dataclass(slots=True)
class CPUTimes:
    """CPU Times."""

    user: float | None = None
    system: float | None = None
    idle: float | None = None
    interrupt: float | None = None
    dpc: float | None = None


@filter_unexpected_fields
@dataclass(slots=True)
class PerCPU:
    """Per CPU."""

    id: int
    frequency: CPUFrequency | None = None
    power: float | None = None
    times: CPUTimes | None = None
    times_percent: CPUTimes | None = None
    usage: float | None = None
    voltage: float | None = None

    def __post_init__(self) -> None:
        """Post Init."""
        if isinstance(self.frequency, dict):
            self.frequency = CPUFrequency(**self.frequency)

        if isinstance(self.times, dict):
            self.times = CPUTimes(**self.times)

        if isinstance(self.times_percent, dict):
            self.times_percent = CPUTimes(**self.times_percent)


@filter_unexpected_fields
@dataclass(slots=True)
class CPU:
    """CPU."""

    count: int | None = None
    frequency: CPUFrequency | None = None
    load_average: float | None = None
    per_cpu: list[PerCPU] | None = None
    power: float | None = None
    stats: CPUStats | None = None
    temperature: float | None = None
    times: CPUTimes | None = None
    times_percent: CPUTimes | None = None
    usage: float | None = None
    voltage: float | None = None

    def __post_init__(self) -> None:
        """Post Init."""
        if isinstance(self.frequency, dict):
            self.frequency = CPUFrequency(**self.frequency)

        if isinstance(self.per_cpu, list) and all(
            isinstance(item, dict) for item in self.per_cpu
        ):
            new_per_cpu: list[PerCPU] = []
            for p in self.per_cpu:
                per_cpu: dict = cast(dict, p)
                frequency = per_cpu.get("frequency")
                times = per_cpu.get("times")
                times_percent = per_cpu.get("times_percent")
                new_per_cpu.append(
                    PerCPU(
                        id=per_cpu["id"],
                        frequency=CPUFrequency(**frequency) if frequency else None,
                        power=per_cpu["power"],
                        times=CPUTimes(**times) if times else None,
                        times_percent=CPUTimes(**times_percent)
                        if times_percent
                        else None,
                        usage=per_cpu["usage"],
                        voltage=per_cpu["voltage"],
                    )
                )
            self.per_cpu = new_per_cpu

        if isinstance(self.stats, dict):
            self.stats = CPUStats(**self.stats)

        if isinstance(self.times, dict):
            self.times = CPUTimes(**self.times)

        if isinstance(self.times_percent, dict):
            self.times_percent = CPUTimes(**self.times_percent)



"""Media Play."""
from __future__ import annotations

from dataclasses import dataclass


@dataclass(slots=True)
class MediaPlay:
    """Media Play."""

    url: str
    album: str | None = None
    artist: str | None = None
    autoplay: bool | None = False
    cover: str | None = None
    title: str | None = None
    volume: float | None = 40



"""Media Control."""
from __future__ import annotations

from dataclasses import dataclass
from enum import Enum
from typing import Any


class MediaAction(Enum):
    """Media Action."""

    PLAY = "PLAY"
    PAUSE = "PAUSE"
    STOP = "STOP"
    PREVIOUS = "PREVIOUS"
    NEXT = "NEXT"
    SEEK = "SEEK"
    REWIND = "REWIND"
    FASTFORWARD = "FASTFORWARD"
    SHUFFLE = "SHUFFLE"
    REPEAT = "REPEAT"
    MUTE = "MUTE"
    VOLUMEDOWN = "VOLUMEDOWN"
    VOLUMEUP = "VOLUMEUP"


@dataclass(slots=True)
class MediaControl:
    """Media Control."""

    action: str
    value: Any | None = None



"""Fixture for cpu module."""
from systembridgemodels.modules.cpu import CPU, CPUFrequency, CPUStats, CPUTimes, PerCPU

FIXTURE_CPU = CPU(
    count=4,
    frequency=CPUFrequency(
        current=2.3,
        min=0.8,
        max=3.1,
    ),
    load_average=1.5,
    per_cpu=[
        PerCPU(
            id=0,
            frequency=CPUFrequency(
                current=2.3,
                min=0.8,
                max=3.1,
            ),
            power=50.0,
            times=CPUTimes(
                user=120.0,
                system=30.0,
                idle=600.0,
                interrupt=0.0,
                dpc=0.0,
            ),
            times_percent=CPUTimes(
                user=20.0,
                system=5.0,
                idle=100.0,
                interrupt=0.0,
                dpc=0.0,
            ),
            usage=20.0,
            voltage=1.2,
        )
    ],
    power=200.0,
    stats=CPUStats(
        ctx_switches=1000,
        interrupts=500,
        soft_interrupts=200,
        syscalls=8000,
    ),
    temperature=45.0,
    times=CPUTimes(
        user=480.0,
        system=120.0,
        idle=2400.0,
        interrupt=0.0,
        dpc=0.0,
    ),
    times_percent=CPUTimes(
        user=80.0,
        system=20.0,
        idle=400.0,
        interrupt=0.0,
        dpc=0.0,
    ),
    usage=80.0,
    voltage=1.2,
)



"""Test the keyboard_key model."""

from syrupy.assertion import SnapshotAssertion

from systembridgemodels.keyboard_key import KeyboardKey


def test_keyboard_key(snapshot: SnapshotAssertion):
    """Test the keyboard_key."""
    keyboard_key = KeyboardKey(
        key="A",
    )
    assert isinstance(keyboard_key, KeyboardKey)
    assert keyboard_key == snapshot



"""Media Files."""
from __future__ import annotations

from dataclasses import dataclass
from typing import cast


@dataclass(slots=True)
class MediaFile:
    """Media File."""

    name: str
    path: str
    fullpath: str
    size: int
    last_accessed: float
    created: float
    modified: float
    is_directory: bool
    is_file: bool
    is_link: bool
    mime_type: str | None = None


@dataclass(slots=True)
class MediaFiles:
    """Media Files."""

    files: list[MediaFile]
    path: str

    def __post_init__(self) -> None:
        """Post Init."""
        if isinstance(self.files, list) and all(
            isinstance(item, dict) for item in self.files
        ):
            new_files: list[MediaFile] = []
            for f in self.files:
                file: dict = cast(dict, f)
                new_files.append(MediaFile(**file))
            self.files = new_files



"""Test the media_directories model."""

from syrupy.assertion import SnapshotAssertion

from systembridgemodels.media_directories import MediaDirectory


def test_media_directories(snapshot: SnapshotAssertion):
    """Test the media_directories."""
    media_directories = [
        MediaDirectory(
            key="music",
            path="path/to/file",
        )
    ]
    assert isinstance(media_directories, list)
    assert isinstance(media_directories[0], MediaDirectory)
    assert media_directories == snapshot



"""Helper functions for systembridge models."""

from dataclasses import fields


def filter_unexpected_fields(cls):
    """Filter unexpected fields from a dataclass.

    Useful when using **kwargs in __init__.
    """
    original_init = cls.__init__

    def new_init(self, *args, **kwargs):
        expected_fields = {field.name for field in fields(cls)}
        cleaned_kwargs = {
            key: value for key, value in kwargs.items() if key in expected_fields
        }
        original_init(self, *args, **cleaned_kwargs)

    cls.__init__ = new_init
    return cls



"""Request."""
from __future__ import annotations

from dataclasses import dataclass, field
from typing import Any


@dataclass(slots=True)
class Request:
    """Request."""

    token: str = field(repr=False)
    id: str
    event: str
    data: dict[str, Any]



"""Setup."""
from setuptools import find_packages, setup

with open("README.md", encoding="utf-8") as f:
    readme = f.read()

setup(
    name="systembridgemodels",
    version="4.2.6",
    author="Aidan Timson (Timmo)",
    author_email="aidan@timmo.dev",
    description="System Bridge Models",
    keywords="system-bridge",
    license="Apache-2.0",
    long_description=readme,
    long_description_content_type="text/markdown",
    url="https://github.com/timmo001/system-bridge-models",
    packages=find_packages(exclude=["tests", "tests.*", "generator"]),
    python_requires=">=3.11",
)



"""Fixtures for displays module."""
from systembridgemodels.modules.displays import Display

FIXTURE_DISPLAYS = [
    Display(
        id="abc123",
        name="name",
        resolution_horizontal=1920,
        resolution_vertical=1080,
        x=1920,
        y=1080,
        width=1920,
        height=1080,
        is_primary=True,
        pixel_clock=60.0,
        refresh_rate=60.0,
    )
]



"""System."""
from __future__ import annotations

from dataclasses import dataclass, field
from enum import Enum
from uuid import uuid4


def generate_token() -> str:
    """Generate token."""
    return str(uuid4())


class SettingAPIEnum(Enum):
    """Setting API Enum."""

    TOKEN = "token"
    PORT = "port"


class SettingHotkeyEnum(Enum):
    """Setting Hotkey Enum."""

    NAME = "name"
    KEY = "key"


class SettingDirectoryEnum(Enum):
    """Setting Media Directory Enum."""

    NAME = "name"
    PATH = "path"


class SettingMediaEnum(Enum):
    """Setting Media Enum."""

    DIRECTORIES = "directories"


class SettingEnum(Enum):
    """Setting Enum."""

    API = "api"
    AUTOSTART = "autostart"
    KEYBOARD_HOTKEYS = "keyboard_hotkeys"
    LOG_LEVEL = "log_level"
    MEDIA = "media"


@dataclass
class SettingsAPI:
    """Settings API."""

    token: str = field(default_factory=generate_token)
    port: int = field(default=9170)


@dataclass
class SettingHotkey:
    """Setting Hotkey."""

    name: str
    key: str


@dataclass
class SettingDirectory:
    """Setting Directory."""

    name: str
    path: str


@dataclass
class SettingsMedia:
    """Settings Media."""

    directories: list[SettingDirectory] = field(default_factory=lambda: [])


@dataclass
class Settings:
    """Settings."""

    api: SettingsAPI = field(default_factory=SettingsAPI)
    autostart: bool = field(default=False)
    keyboard_hotkeys: list[SettingHotkey] = field(default_factory=lambda: [])
    log_level: str = field(default="INFO")
    media: SettingsMedia = field(default_factory=SettingsMedia)



"""Networks."""

from __future__ import annotations

from dataclasses import dataclass
from typing import cast

from ..helpers import filter_unexpected_fields


@filter_unexpected_fields
@dataclass(slots=True)
class NetworkAddress:
    """Network Address."""

    address: str | None = None
    family: str | None = None
    netmask: str | None = None
    broadcast: str | None = None
    ptp: str | None = None


@filter_unexpected_fields
@dataclass(slots=True)
class NetworkStats:
    """Network Stats."""

    isup: bool | None = None
    duplex: str | None = None
    speed: int | None = None
    mtu: int | None = None
    flags: list[str] | None = None


@filter_unexpected_fields
@dataclass(slots=True)
class NetworkConnection:
    """Network Connection."""

    fd: int | None = None
    family: int | None = None
    type: int | None = None
    laddr: str | None = None
    raddr: str | None = None
    status: str | None = None
    pid: int | None = None


@filter_unexpected_fields
@dataclass(slots=True)
class NetworkIO:
    """Network IO."""

    bytes_sent: int | None = None
    bytes_recv: int | None = None
    packets_sent: int | None = None
    packets_recv: int | None = None
    errin: int | None = None
    errout: int | None = None
    dropin: int | None = None
    dropout: int | None = None


@filter_unexpected_fields
@dataclass(slots=True)
class Network:
    """Network."""

    name: str | None = None
    addresses: list[NetworkAddress] | None = None
    stats: NetworkStats | None = None

    def __post_init__(self) -> None:
        """Post Init."""
        if isinstance(self.addresses, list) and all(
            isinstance(item, dict) for item in self.addresses
        ):
            new_addresses: list[NetworkAddress] = []
            for a in self.addresses:
                address: dict = cast(dict, a)
                new_addresses.append(NetworkAddress(**address))
            self.addresses = new_addresses

        if isinstance(self.stats, dict):
            stats = self.stats
            self.stats = NetworkStats(**stats)


@filter_unexpected_fields
@dataclass(slots=True)
class Networks:
    """Networks."""

    connections: list[NetworkConnection] | None = None
    io: NetworkIO | None = None
    networks: list[Network] | None = None

    def __post_init__(self) -> None:
        """Post Init."""
        if isinstance(self.connections, list) and all(
            isinstance(item, dict) for item in self.connections
        ):
            new_connections: list[NetworkConnection] = []
            for c in self.connections:
                connection: dict = cast(dict, c)
                new_connections.append(NetworkConnection(**connection))
            self.connections = new_connections

        if isinstance(self.io, dict):
            io = self.io
            self.io = NetworkIO(**io)

        if isinstance(self.networks, list) and all(
            isinstance(item, dict) for item in self.networks
        ):
            new_networks: list[Network] = []
            for n in self.networks:
                network: dict = cast(dict, n)
                new_networks.append(Network(**network))
            self.networks = new_networks



"""Fixture for sensors module."""
from systembridgemodels.modules.sensors import (
    Sensors,
    SensorsNVIDIA,
    SensorsNVIDIAChipset,
    SensorsNVIDIADisplay,
    SensorsNVIDIADriver,
    SensorsNVIDIAGPU,
    SensorsWindows,
    SensorsWindowsHardware,
    SensorsWindowsSensor,
)

FIXTURE_SENSORS = Sensors(
    fans=None,
    temperatures=None,
    windows_sensors=SensorsWindows(
        hardware=[
            SensorsWindowsHardware(
                id="id",
                name="name",
                type="type",
                subhardware=[
                    SensorsWindowsHardware(
                        id="id",
                        name="name",
                        type="type",
                        subhardware=[],
                        sensors=[
                            SensorsWindowsSensor(
                                id="id",
                                name="name",
                                type="type",
                                value=12.3,
                            )
                        ],
                    )
                ],
                sensors=[
                    SensorsWindowsSensor(
                        id="id",
                        name="name",
                        type="type",
                        value=12.3,
                    )
                ],
            )
        ],
        nvidia=SensorsNVIDIA(
            chipset=SensorsNVIDIAChipset(
                id=1234,
                name="name",
                flags="flags",
                vendor_id=1234,
                vendor_name="Vendor Name",
            ),
            displays=[
                SensorsNVIDIADisplay(
                    id=1234,
                    name="name",
                    active=True,
                    available=True,
                    connected=True,
                    dynamic=True,
                    aspect_horizontal=16,
                    aspect_vertical=9,
                    brightness_current=90,
                    brightness_default=80,
                    brightness_max=100,
                    brightness_min=0,
                    color_depth="Color Depth",
                    connection_type="Connection Type",
                    pixel_clock=60,
                    refresh_rate=144,
                    resolution_horizontal=1920,
                    resolution_vertical=1080,
                )
            ],
            driver=SensorsNVIDIADriver(
                branch_version="Branch Version",
                interface_version="Interface Version",
                version=1234,
            ),
            gpus=[
                SensorsNVIDIAGPU(
                    id=1234,
                    name="name",
                    bios_oem_revision=1234,
                    bios_revision=1234,
                    bios_version="bios_version",
                    current_fan_speed_level=1234,
                    current_fan_speed_rpm=1234,
                    driver_model=1234,
                    memory_available=1234,
                    memory_capacity=1234,
                    memory_maker="Memory Maker",
                    serial="abc123",
                    system_type="System Type",
                    type="Type",
                )
            ],
        ),
    ),
)
